#ifndef XERROR_H
#define XERROR_H
void x_message(const char *text, ...);
void x_error(const char *text, ...);
void x_fatalerror(const char *text, ...);
#endif
